Default

Trait Default 

1.85.0 (const: unstable) · Source
pub trait Default: Sized {
    // Required method
    fn default() -> Self;
}
A trait for giving a type a useful default value.

Sometimes, you want to fall back to some kind of default value, and don’t particularly care what it is. This comes up often with structs that define a set of options:

struct SomeOptions {
    foo: i32,
    bar: f32,
}

How can we define some default values? You can use Default:

#[derive(Default)]
struct SomeOptions {
    foo: i32,
    bar: f32,
}

fn main() {
    let options: SomeOptions = Default::default();
}

Now, you get all of the default values. Rust implements Default for various primitive types.

If you want to override a particular option, but still retain the other defaults:

fn main() {
    let options = SomeOptions { foo: 42, ..Default::default() };
}

Derivable

This trait can be used with #[derive] if all of the type’s fields implement Default. When derived, it will use the default value for each field’s type.

enums

When using #[derive(Default)] on an enum, you need to choose which unit variant will be default. You do this by placing the #[default] attribute on the variant.

#[derive(Default)]
enum Kind {
    #[default]
    A,
    B,
    C,
}

You cannot use the #[default] attribute on non-unit or non-exhaustive variants.

The #[default] attribute was stabilized in Rust 1.62.0.

How can I implement Default?

Provide an implementation for the default() method that returns the value of your type that should be the default:

enum Kind {
    A,
    B,
    C,
}

impl Default for Kind {
    fn default() -> Self { Kind::A }
}

Examples

#[derive(Default)]
struct SomeOptions {
    foo: i32,
    bar: f32,
}

Required Methods

1.0.0 · Source

fn default() -> Self

Returns the “default value” for a type.

Default values are often some kind of initial value, identity value, or anything else that may make sense as a default.

Examples

Using built-in default values:

let i: i8 = Default::default();
let (x, y): (Option<String>, f64) = Default::default();
let (a, b, (c, d)): (i32, u32, (bool, bool)) = Default::default();

Making your own:

enum Kind {
    A,
    B,
    C,
}

impl Default for Kind {
    fn default() -> Self { Kind::A }
}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

1.0.0 (const: unstable) · Source

impl Default for &str

1.10.0 · Source

impl Default for &CStr

1.9.0 · Source

impl Default for &OsStr

1.28.0 (const: unstable) · Source

impl Default for &mut str

Source

impl Default for PrefilterConfig

Source

impl Default for Endianness

Source

impl Default for Name

Source

impl Default for MemoryInitialization

1.0.0 (const: unstable) · Source

impl Default for AsciiChar

Source

impl Default for Abi

1.0.0 (const: unstable) · Source

impl Default for bool

1.0.0 (const: unstable) · Source

impl Default for char

1.0.0 (const: unstable) · Source

impl Default for f16

1.0.0 (const: unstable) · Source

impl Default for f32

1.0.0 (const: unstable) · Source

impl Default for f64

1.0.0 (const: unstable) · Source

impl Default for f128

1.0.0 (const: unstable) · Source

impl Default for i8

1.0.0 (const: unstable) · Source

impl Default for i16

1.0.0 (const: unstable) · Source

impl Default for i32

1.0.0 (const: unstable) · Source

impl Default for i64

1.0.0 (const: unstable) · Source

impl Default for i128

1.0.0 (const: unstable) · Source

impl Default for isize

1.0.0 (const: unstable) · Source

impl Default for u8

1.0.0 (const: unstable) · Source

impl Default for u16

1.0.0 (const: unstable) · Source

impl Default for u32

1.0.0 (const: unstable) · Source

impl Default for u64

1.0.0 (const: unstable) · Source

impl Default for u128

1.0.0 (const: unstable) · Source

impl Default for ()

1.0.0 (const: unstable) · Source

impl Default for usize

Source

impl Default for AHasher

Provides a default Hasher with fixed keys. This is typically used in conjunction with BuildHasherDefault to create AHashers in order to hash the keys of the map.

Generally it is preferable to use RandomState instead, so that different hashmaps will have different keys. However if fixed keys are desirable this may be used instead.

Example

use std::hash::BuildHasherDefault;
use ahash::{AHasher, RandomState};
use std::collections::HashMap;

let mut map: HashMap<i32, i32, BuildHasherDefault<AHasher>> = HashMap::default();
map.insert(12, 34);
Source

impl Default for ahash::random_state::RandomState

Available on crate features compile-time-rng or runtime-rng or no-rng only.

Creates an instance of RandomState using keys obtained from the random number generator. Each instance created in this way will have a unique set of keys. (But the resulting instance can be used to create many hashers each or which will have the same keys.)

This is the same as RandomState::new()

NOTE: For safety this trait impl is only available available if either of the flags runtime-rng (on by default) or compile-time-rng are enabled. This is to prevent weakly keyed maps from being accidentally created. Instead one of constructors for RandomState must be used.

Source

impl Default for anyhow::Chain<'_>

Available on crate feature std or non-anyhow_no_core_error only.
Source

impl Default for EncoderState

Source

impl Default for CompoundBitSet

Source

impl Default for Hasher

Source

impl Default for DefaultHashBuilder

Source

impl Default for MetadataBuilder<'_>

Source

impl Default for RecordBuilder<'_>

Source

impl Default for FinderBuilder

Source

impl Default for object::endian::BigEndian

Source

impl Default for object::endian::LittleEndian

Source

impl Default for ImageSectionHeader

Source

impl Default for RelocationSections

Source

impl Default for VersionIndex

Source

impl Default for object::read::pe::relocation::Relocation

Source

impl Default for RelocationMap

Source

impl Default for AuxSymbolSection

Source

impl Default for FileHeader

Source

impl Default for object::write::coff::writer::Relocation

Source

impl Default for SectionHeader

Source

impl Default for Symbol

Source

impl Default for Class

Source

impl Default for SectionIndex

Source

impl Default for SymbolIndex

Source

impl Default for MachOBuildVersion

Source

impl Default for SectionRange

Source

impl Default for OnceBool

Source

impl Default for OnceNonZeroUsize

Source

impl Default for AllocVec

Source

impl Default for Size

Source

impl Default for IgnoredAny

Source

impl Default for DefaultToHost

Source

impl Default for DefaultToUnknown

1.17.0 · Source

impl Default for wasmtime_environ::prelude::Box<str>

Available on non-no_global_oom_handling only.
1.17.0 · Source

impl Default for wasmtime_environ::prelude::Box<CStr>

1.17.0 · Source

impl Default for wasmtime_environ::prelude::Box<OsStr>

1.0.0 (const: unstable) · Source

impl Default for String

Source

impl Default for AddressMapSection

Source

impl Default for FilePos

Source

impl Default for Module

Source

impl Default for ModuleTypes

Source

impl Default for TableInitialization

Source

impl Default for TrapEncodingBuilder

Source

impl Default for VMSharedTypeIndex

Source

impl Default for WasmFileInfo

Source

impl Default for WasmFunctionInfo



impl Default for wasmtime_environ::wasmparser::collections::hash::RandomState



impl Default for FuncValidatorAllocations



impl Default for Parser



impl Default for SegmentFlags



impl Default for SymbolFlags



impl Default for Validator



impl Default for ValidatorId



impl Default for WasmFeatures

Available on crate feature features only.


impl Default for Remapping

1.0.0 · Source

impl Default for Error

Source

impl Default for FormattingOptions

1.0.0 · Source

impl Default for SipHasher

1.33.0 · Source

impl Default for PhantomPinned

1.0.0 (const: unstable) · Source

impl Default for RangeFull

Source

impl Default for Alignment

Returns Alignment::MIN, which is valid for any type.

1.0.0 · Source

impl Default for AtomicBool

Available on target_has_atomic_load_store=8 only.
1.34.0 · Source

impl Default for AtomicI8

1.34.0 · Source

impl Default for AtomicI16

1.34.0 · Source

impl Default for AtomicI32

1.34.0 · Source

impl Default for AtomicI64

1.0.0 · Source

impl Default for AtomicIsize

1.34.0 · Source

impl Default for AtomicU8

1.34.0 · Source

impl Default for AtomicU16

1.34.0 · Source

impl Default for AtomicU32

1.34.0 · Source

impl Default for AtomicU64

1.0.0 · Source

impl Default for AtomicUsize

1.3.0 · Source

impl Default for Duration

Source

impl Default for alloc::alloc::Global

Source

impl Default for ByteString

1.10.0 · Source

impl Default for CString

1.80.0 · Source

impl Default for Rc<str>

Available on non-no_global_oom_handling only.
1.80.0 · Source

impl Default for Rc<CStr>

Available on non-no_global_oom_handling only.
1.80.0 · Source

impl Default for Arc<str>

Available on non-no_global_oom_handling only.
1.80.0 · Source

impl Default for Arc<CStr>

Available on non-no_global_oom_handling only.
1.28.0 · Source

impl Default for System

1.9.0 · Source

impl Default for OsString

1.75.0 · Source

impl Default for FileTimes

1.13.0 (const: unstable) · Source

impl Default for DefaultHasher

1.7.0 · Source

impl Default for std::hash::random::RandomState

1.0.0 · Source

impl Default for std::io::util::Empty

1.0.0 · Source

impl Default for Sink

1.17.0 · Source

impl Default for PathBuf

1.75.0 · Source

impl Default for ExitCode

The default value is ExitCode::SUCCESS

1.73.0 · Source

impl Default for ExitStatus

The default value is one which indicates successful completion.

Source

impl Default for DefaultRandomSource

Source

impl Default for std::sync::nonpoison::condvar::Condvar

1.10.0 · Source

impl Default for std::sync::poison::condvar::Condvar

Source

impl Default for BuildMetadata

Source

impl Default for Prerelease

Source

impl Default for VersionReq

Available on non-no_const_vec_new only.

The default VersionReq is the same as VersionReq::STAR.



impl Default for Abbreviations



impl Default for AbbreviationsCache



impl Default for Augmentation



impl Default for BaseAddresses



impl Default for BigEndian



impl Default for DebugInfoOffsets



impl Default for Dwarf



impl Default for DwarfFileType



impl Default for Expression



impl Default for FileInfo



impl Default for FrameTable



impl Default for Global



impl Default for LineEncoding



impl Default for LineStringTable



impl Default for LittleEndian



impl Default for LocationListTable



impl Default for Pointer



impl Default for RangeListTable



impl Default for RunTimeEndian



impl Default for SectionBaseAddresses



impl Default for StringTable



impl Default for UnitTable

Source

impl<'a> Default for &'a ByteStr

Source

impl<'a> Default for &'a mut ByteStr

Source

impl<'a> Default for DebugInfoData<'a>

Source

impl<'a> Default for NameSection<'a>

Source

impl<'a> Default for PhantomContravariantLifetime<'a>

Source

impl<'a> Default for PhantomCovariantLifetime<'a>

Source

impl<'a> Default for PhantomInvariantLifetime<'a>

1.70.0 · Source

impl<'a, K, V> Default for alloc::collections::btree::map::Iter<'a, K, V>
where K: 'a, V: 'a,

1.70.0 · Source

impl<'a, K, V> Default for alloc::collections::btree::map::IterMut<'a, K, V>
where K: 'a, V: 'a,

Source

impl<'a, T> Default for OnceRef<'a, T>

Source

impl<'data> Default for object::read::coff::section::SectionTable<'data>

Source

impl<'data> Default for Version<'data>

Source

impl<'data> Default for RelocationBlockIterator<'data>

Source

impl<'data> Default for ObjectMap<'data>

Source

impl<'data> Default for ObjectMapEntry<'data>

Source

impl<'data> Default for Bytes<'data>

Source

impl<'data> Default for ModuleTranslation<'data>

Source

impl<'data, E> Default for LoadCommandIterator<'data, E>
where E: Default + Endian,

Source

impl<'data, Elf> Default for VersionTable<'data, Elf>
where Elf: FileHeader,

Source

impl<'data, Elf, R> Default for object::read::elf::section::SectionTable<'data, Elf, R>
where Elf: FileHeader, R: ReadRef<'data>,

Source

impl<'data, Elf, R> Default for object::read::elf::symbol::SymbolTable<'data, Elf, R>
where Elf: FileHeader, R: ReadRef<'data>,

Source

impl<'data, Mach, R> Default for object::read::macho::symbol::SymbolTable<'data, Mach, R>
where Mach: MachHeader, R: ReadRef<'data>,

Source

impl<'data, R> Default for object::read::util::StringTable<'data, R>
where R: ReadRef<'data>,

Source

impl<'data, R, Coff> Default for object::read::coff::symbol::SymbolTable<'data, R, Coff>
where R: ReadRef<'data>, Coff: CoffHeader,

Source

impl<'data, Xcoff> Default for object::read::xcoff::section::SectionTable<'data, Xcoff>
where Xcoff: FileHeader,

Source

impl<'data, Xcoff, R> Default for object::read::xcoff::symbol::SymbolTable<'data, Xcoff, R>
where Xcoff: FileHeader, R: ReadRef<'data>,



impl<'input, Endian> Default for EndianSlice<'input, Endian>
where Endian: Default + Endianity,

Source

impl<A> Default for SmallVec<A>
where A: Array,



impl<A> Default for Box<str, A>
where A: Allocator + Default,

1.70.0 · Source

impl<A, B> Default for wasmtime_environ::__core::iter::Chain<A, B>
where A: Default, B: Default,

1.11.0 · Source

impl<B> Default for Cow<'_, B>
where B: ToOwned + ?Sized, <B as ToOwned>::Owned: Default,

Source

impl<E> Default for CompressionHeader32<E>
where E: Default + Endian,

Source

impl<E> Default for CompressionHeader64<E>
where E: Default + Endian,

Source

impl<E> Default for Sym32<E>
where E: Default + Endian,

Source

impl<E> Default for Sym64<E>
where E: Default + Endian,

Source

impl<E> Default for I16Bytes<E>
where E: Default + Endian,

Source

impl<E> Default for I32Bytes<E>
where E: Default + Endian,

Source

impl<E> Default for I64Bytes<E>
where E: Default + Endian,

Source

impl<E> Default for U16Bytes<E>
where E: Default + Endian,

Source

impl<E> Default for U32Bytes<E>
where E: Default + Endian,

Source

impl<E> Default for U64Bytes<E>
where E: Default + Endian,

1.7.0 (const: unstable) · Source

impl<H> Default for BuildHasherDefault<H>

1.70.0 · Source

impl<I> Default for Cloned<I>
where I: Default,

1.70.0 · Source

impl<I> Default for Copied<I>
where I: Default,

1.70.0 · Source

impl<I> Default for Enumerate<I>
where I: Default,

1.70.0 · Source

impl<I> Default for Flatten<I>
where I: Default + Iterator, <I as Iterator>::Item: IntoIterator,

1.70.0 · Source

impl<I> Default for Fuse<I>
where I: Default,

1.70.0 · Source

impl<I> Default for Rev<I>
where I: Default,

1.0.0 (const: unstable) · Source

impl<Idx> Default for wasmtime_environ::__core::ops::Range<Idx>
where Idx: Default,

Source

impl<Idx> Default for wasmtime_environ::__core::range::Range<Idx>
where Idx: Default,

Source

impl<K> Default for hashbrown::set::Iter<'_, K>

Source

impl<K> Default for EntitySet<K>
where K: EntityRef,

1.83.0 · Source

impl<K> Default for std::collections::hash::set::IntoIter<K>

1.83.0 · Source

impl<K> Default for std::collections::hash::set::Iter<'_, K>

Source

impl<K, A> Default for hashbrown::set::IntoIter<K, A>
where A: Allocator,

Source

impl<K, V> Default for &indexmap::map::slice::Slice<K, V>

Source

impl<K, V> Default for &mut indexmap::map::slice::Slice<K, V>

Source

impl<K, V> Default for AHashMap<K, V>

Available on crate features compile-time-rng or runtime-rng or no-rng only.

NOTE: For safety this trait impl is only available if either of the flags runtime-rng (on by default) or compile-time-rng are enabled. This is to prevent weakly keyed maps from being accidentally created. Instead one of constructors for RandomState must be used.

Source

impl<K, V> Default for hashbrown::map::Iter<'_, K, V>

Source

impl<K, V> Default for hashbrown::map::IterMut<'_, K, V>

Source

impl<K, V> Default for hashbrown::map::Keys<'_, K, V>

Source

impl<K, V> Default for hashbrown::map::Values<'_, K, V>

Source

impl<K, V> Default for hashbrown::map::ValuesMut<'_, K, V>

Source

impl<K, V> Default for indexmap::map::iter::IntoIter<K, V>

Source

impl<K, V> Default for indexmap::map::iter::IntoKeys<K, V>

Source

impl<K, V> Default for indexmap::map::iter::IntoValues<K, V>

Source

impl<K, V> Default for indexmap::map::iter::Iter<'_, K, V>

Source

impl<K, V> Default for IterMut2<'_, K, V>

Source

impl<K, V> Default for indexmap::map::iter::IterMut<'_, K, V>

Source

impl<K, V> Default for indexmap::map::iter::Keys<'_, K, V>

Source

impl<K, V> Default for indexmap::map::iter::Values<'_, K, V>

Source

impl<K, V> Default for indexmap::map::iter::ValuesMut<'_, K, V>

Source

impl<K, V> Default for wasmtime_environ::prelude::Box<Slice<K, V>>



impl<K, V> Default for wasmtime_environ::prelude::IndexMap<K, V>

Source

impl<K, V> Default for PrimaryMap<K, V>
where K: EntityRef,

Source

impl<K, V> Default for SecondaryMap<K, V>
where K: EntityRef, V: Clone + Default,



impl<K, V> Default for Map<K, V>

1.0.0 · Source

impl<K, V> Default for BTreeMap<K, V>

1.70.0 · Source

impl<K, V> Default for alloc::collections::btree::map::Keys<'_, K, V>

1.70.0 · Source

impl<K, V> Default for alloc::collections::btree::map::Range<'_, K, V>

1.82.0 · Source

impl<K, V> Default for RangeMut<'_, K, V>

1.70.0 · Source

impl<K, V> Default for alloc::collections::btree::map::Values<'_, K, V>

1.82.0 · Source

impl<K, V> Default for alloc::collections::btree::map::ValuesMut<'_, K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::IntoIter<K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::IntoKeys<K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::IntoValues<K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::Iter<'_, K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::IterMut<'_, K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::Keys<'_, K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::Values<'_, K, V>

1.83.0 · Source

impl<K, V> Default for std::collections::hash::map::ValuesMut<'_, K, V>

Source

impl<K, V, A> Default for hashbrown::map::IntoIter<K, V, A>
where A: Allocator,

Source

impl<K, V, A> Default for hashbrown::map::IntoKeys<K, V, A>
where A: Allocator,

Source

impl<K, V, A> Default for hashbrown::map::IntoValues<K, V, A>
where A: Allocator,

1.70.0 · Source

impl<K, V, A> Default for alloc::collections::btree::map::IntoIter<K, V, A>
where A: Allocator + Default + Clone,

1.70.0 · Source

impl<K, V, A> Default for alloc::collections::btree::map::IntoKeys<K, V, A>
where A: Allocator + Default + Clone,

1.70.0 · Source

impl<K, V, A> Default for alloc::collections::btree::map::IntoValues<K, V, A>
where A: Allocator + Default + Clone,

Source

impl<K, V, S> Default for indexmap::map::IndexMap<K, V, S>
where S: Default,

1.0.0 (const: unstable) · Source

impl<K, V, S> Default for std::collections::hash::map::HashMap<K, V, S>
where S: Default,

Source

impl<K, V, S, A> Default for hashbrown::map::HashMap<K, V, S, A>
where S: Default, A: Default + Allocator,

Source

impl<K, V, S, A> Default for hashbrown::map::HashMap<K, V, S, A>
where S: Default, A: Default + Allocator,

Source

impl<O> Default for F32<O>

Source

impl<O> Default for F64<O>

Source

impl<O> Default for I16<O>

Source

impl<O> Default for I32<O>

Source

impl<O> Default for I64<O>

Source

impl<O> Default for I128<O>

Source

impl<O> Default for Isize<O>

Source

impl<O> Default for U16<O>

Source

impl<O> Default for U32<O>

Source

impl<O> Default for U64<O>

Source

impl<O> Default for U128<O>

Source

impl<O> Default for Usize<O>

Source

impl<P> Default for MaybeDangling<P>
where P: Default + ?Sized,



impl<R> Default for DebugAbbrev<R>
where R: Default,



impl<R> Default for DebugAddr<R>
where R: Default,



impl<R> Default for DebugAranges<R>
where R: Default,



impl<R> Default for DebugCuIndex<R>
where R: Default,



impl<R> Default for DebugInfo<R>
where R: Default,



impl<R> Default for DebugLine<R>
where R: Default,



impl<R> Default for DebugLineStr<R>
where R: Default,



impl<R> Default for DebugLoc<R>
where R: Default,



impl<R> Default for DebugLocLists<R>
where R: Default,



impl<R> Default for DebugRanges<R>
where R: Default,



impl<R> Default for DebugRngLists<R>
where R: Default,



impl<R> Default for DebugStr<R>
where R: Default,



impl<R> Default for DebugStrOffsets<R>
where R: Default,



impl<R> Default for DebugTuIndex<R>
where R: Default,



impl<R> Default for DebugTypes<R>
where R: Default,



impl<R> Default for Dwarf<R>
where R: Default,



impl<R> Default for LocationLists<R>
where R: Default,



impl<R> Default for RangeIter<R>
where R: Reader,



impl<R> Default for RangeLists<R>
where R: Default,

1.0.0 (const: unstable) · Source

impl<T> Default for &[T]

Source

impl<T> Default for &indexmap::set::slice::Slice<T>

1.5.0 (const: unstable) · Source

impl<T> Default for &mut [T]

1.0.0 (const: unstable) · Source

impl<T> Default for Option<T>

1.4.0 · Source

impl<T> Default for [T; 0]

1.4.0 · Source

impl<T> Default for [T; 1]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 2]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 3]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 4]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 5]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 6]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 7]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 8]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 9]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 10]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 11]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 12]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 13]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 14]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 15]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 16]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 17]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 18]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 19]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 20]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 21]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 22]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 23]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 24]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 25]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 26]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 27]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 28]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 29]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 30]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 31]
where T: Default,

1.4.0 · Source

impl<T> Default for [T; 32]
where T: Default,

1.88.0 · Source

impl<T> Default for *const T
where T: Thin + ?Sized,

1.88.0 · Source

impl<T> Default for *mut T
where T: Thin + ?Sized,

1.0.0 · Source

impl<T> Default for (T₁, T₂, …, Tₙ)
where T: Default,

This trait is implemented for tuples up to twelve items long.

Source

impl<T> Default for AHashSet<T>

Available on crate features compile-time-rng or runtime-rng or no-rng only.

NOTE: For safety this trait impl is only available available if either of the flags runtime-rng (on by default) or compile-time-rng are enabled. This is to prevent weakly keyed maps from being accidentally created. Instead one of constructors for RandomState must be used.

Source

impl<T> Default for ScalarBitSet<T>

Source

impl<T> Default for hashbrown::table::Iter<'_, T>

Source

impl<T> Default for IterBuckets<'_, T>

Source

impl<T> Default for IterHash<'_, T>

Source

impl<T> Default for IterHashBuckets<'_, T>

Source

impl<T> Default for IterHashMut<'_, T>

Source

impl<T> Default for hashbrown::table::IterMut<'_, T>

Source

impl<T> Default for UnsafeIter<'_, T>

Source

impl<T> Default for indexmap::set::iter::IntoIter<T>

Source

impl<T> Default for indexmap::set::iter::Iter<'_, T>

Source

impl<T> Default for SymbolMap<T>

Source

impl<T> Default for OnceBox<T>

Source

impl<T> Default for once_cell::sync::Lazy<T>
where T: Default,

Source

impl<T> Default for once_cell::sync::OnceCell<T>

Source

impl<T> Default for once_cell::unsync::Lazy<T>
where T: Default,

Source

impl<T> Default for once_cell::unsync::OnceCell<T>

Source

impl<T> Default for Unalign<T>
where T: Default,

Source

impl<T> Default for PackedOption<T>
where T: ReservedValue,

1.0.0 · Source

impl<T> Default for wasmtime_environ::prelude::Box<[T]>

Available on non-no_global_oom_handling only.
Source

impl<T> Default for wasmtime_environ::prelude::Box<Slice<T>>

1.0.0 · Source

impl<T> Default for wasmtime_environ::prelude::Box<T>
where T: Default,

Available on non-no_global_oom_handling only.


impl<T> Default for wasmtime_environ::prelude::IndexSet<T>

1.0.0 (const: unstable) · Source

impl<T> Default for wasmtime_environ::prelude::Vec<T>

Source

impl<T> Default for EntityList<T>

Create an empty list.

Source

impl<T> Default for ListPool<T>



impl<T> Default for Set<T>

1.0.0 (const: unstable) · Source

impl<T> Default for Cell<T>
where T: Default,

1.80.0 · Source

impl<T> Default for LazyCell<T>
where T: Default,

1.70.0 (const: unstable) · Source

impl<T> Default for wasmtime_environ::__core::cell::OnceCell<T>

1.0.0 (const: unstable) · Source

impl<T> Default for RefCell<T>
where T: Default,

Source

impl<T> Default for SyncUnsafeCell<T>
where T: Default,

1.10.0 (const: unstable) · Source

impl<T> Default for UnsafeCell<T>
where T: Default,

1.19.0 (const: unstable) · Source

impl<T> Default for Reverse<T>
where T: Default,

1.2.0 (const: unstable) · Source

impl<T> Default for wasmtime_environ::__core::iter::Empty<T>

Source

impl<T> Default for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Default for PhantomCovariant<T>
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> Default for PhantomData<T>
where T: ?Sized,

Source

impl<T> Default for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> Default for ManuallyDrop<T>
where T: Default + ?Sized,

1.74.0 · Source

impl<T> Default for Saturating<T>
where T: Default,

1.0.0 · Source

impl<T> Default for Wrapping<T>
where T: Default,

1.62.0 · Source

impl<T> Default for AssertUnwindSafe<T>
where T: Default,

1.91.0 · Source

impl<T> Default for Pin<Box<T>>
where Box<T>: Default, T: ?Sized,

Available on non-no_global_oom_handling only.
1.91.0 · Source

impl<T> Default for Pin<Rc<T>>
where Rc<T>: Default, T: ?Sized,

Available on non-no_global_oom_handling only.
1.91.0 · Source

impl<T> Default for Pin<Arc<T>>
where Arc<T>: Default, T: ?Sized,

Available on non-no_global_oom_handling only.
Source

impl<T> Default for UnsafePinned<T>
where T: Default,

1.70.0 · Source

impl<T> Default for wasmtime_environ::__core::slice::Iter<'_, T>

1.70.0 · Source

impl<T> Default for wasmtime_environ::__core::slice::IterMut<'_, T>

1.0.0 · Source

impl<T> Default for AtomicPtr<T>

Available on target_has_atomic_load_store=ptr only.
Source

impl<T> Default for Exclusive<T>
where T: Default + ?Sized,

1.0.0 · Source

impl<T> Default for BinaryHeap<T>

1.70.0 · Source

impl<T> Default for alloc::collections::binary_heap::IntoIter<T>

1.82.0 · Source

impl<T> Default for alloc::collections::binary_heap::Iter<'_, T>

1.0.0 · Source

impl<T> Default for BTreeSet<T>

1.70.0 · Source

impl<T> Default for alloc::collections::btree::set::Iter<'_, T>

1.70.0 · Source

impl<T> Default for alloc::collections::btree::set::Range<'_, T>

1.70.0 · Source

impl<T> Default for alloc::collections::linked_list::IntoIter<T>

1.70.0 · Source

impl<T> Default for alloc::collections::linked_list::Iter<'_, T>

1.70.0 · Source

impl<T> Default for alloc::collections::linked_list::IterMut<'_, T>

1.0.0 · Source

impl<T> Default for LinkedList<T>

1.82.0 · Source

impl<T> Default for alloc::collections::vec_deque::iter::Iter<'_, T>

1.82.0 · Source

impl<T> Default for alloc::collections::vec_deque::iter_mut::IterMut<'_, T>

1.0.0 · Source

impl<T> Default for VecDeque<T>

1.80.0 · Source

impl<T> Default for Rc<[T]>

Available on non-no_global_oom_handling only.
1.0.0 · Source

impl<T> Default for Rc<T>
where T: Default,

Available on non-no_global_oom_handling only.
1.10.0 · Source

impl<T> Default for alloc::rc::Weak<T>

1.80.0 · Source

impl<T> Default for Arc<[T]>

Available on non-no_global_oom_handling only.
1.0.0 · Source

impl<T> Default for Arc<T>
where T: Default,

Available on non-no_global_oom_handling only.
1.10.0 · Source

impl<T> Default for alloc::sync::Weak<T>

1.0.0 · Source

impl<T> Default for Cursor<T>
where T: Default,

1.80.0 · Source

impl<T> Default for LazyLock<T>
where T: Default,

Source

impl<T> Default for std::sync::nonpoison::mutex::Mutex<T>
where T: Default,

Source

impl<T> Default for std::sync::nonpoison::rwlock::RwLock<T>
where T: Default,

1.70.0 (const: unstable) · Source

impl<T> Default for OnceLock<T>

1.10.0 · Source

impl<T> Default for std::sync::poison::mutex::Mutex<T>
where T: Default,

1.10.0 · Source

impl<T> Default for std::sync::poison::rwlock::RwLock<T>
where T: Default,

Source

impl<T> Default for ReentrantLock<T>
where T: Default,



impl<T> Default for Box<T>
where T: Default,

Available on non-no_global_oom_handling only.


impl<T> Default for CfaRule<T>
where T: ReaderOffset,



impl<T> Default for Vec<T>

Source

impl<T, A> Default for RawTable<T, A>
where A: Allocator + Default,

Source

impl<T, A> Default for hashbrown::table::HashTable<T, A>
where A: Allocator + Default,

Source

impl<T, A> Default for hashbrown::table::HashTable<T, A>
where A: Allocator + Default,

Source

impl<T, A> Default for hashbrown::table::IntoIter<T, A>
where A: Allocator,

1.70.0 · Source

impl<T, A> Default for wasmtime_environ::prelude::vec::IntoIter<T, A>
where A: Allocator + Default,

1.70.0 · Source

impl<T, A> Default for alloc::collections::btree::set::IntoIter<T, A>
where A: Allocator + Default + Clone,



impl<T, A> Default for Box<[T], A>
where A: Allocator + Default,



impl<T, A> Default for UnwindContext<T, A>
where T: ReaderOffset, A: UnwindContextStorage<T>,

Source

impl<T, S> Default for indexmap::set::IndexSet<T, S>
where S: Default,

1.0.0 (const: unstable) · Source

impl<T, S> Default for std::collections::hash::set::HashSet<T, S>
where S: Default,



impl<T, S> Default for UnwindTableRow<T, S>
where T: ReaderOffset, S: UnwindContextStorage<T>,

Source

impl<T, S, A> Default for hashbrown::set::HashSet<T, S, A>
where S: Default, A: Default + Allocator,

Source

impl<T, S, A> Default for hashbrown::set::HashSet<T, S, A>
where S: Default, A: Default + Allocator,

1.89.0 · Source

impl<T, const N: usize> Default for wasmtime_environ::__core::array::IntoIter<T, N>

Source

impl<T, const N: usize> Default for Mask<T, N>
where T: MaskElement,

Source

impl<T, const N: usize> Default for Simd<T, N>
where T: SimdElement + Default,



impl<W> Default for DebugAbbrev<W>
where W: Default + Writer,



impl<W> Default for DebugFrame<W>
where W: Default + Writer,



impl<W> Default for DebugInfo<W>
where W: Default + Writer,



impl<W> Default for DebugLine<W>
where W: Default + Writer,



impl<W> Default for DebugLineStr<W>
where W: Default + Writer,



impl<W> Default for DebugLoc<W>
where W: Default + Writer,



impl<W> Default for DebugLocLists<W>
where W: Default + Writer,



impl<W> Default for DebugRanges<W>
where W: Default + Writer,



impl<W> Default for DebugRngLists<W>
where W: Default + Writer,



impl<W> Default for DebugStr<W>
where W: Default + Writer,



impl<W> Default for EhFrame<W>
where W: Default + Writer,



impl<W> Default for Sections<W>
where W: Default + Writer,

Source

impl<const N: usize> Default for CobsAccumulator<N>