PartialEq

Trait PartialEq 

1.85.0 (const: unstable) · Source
pub trait PartialEq<Rhs = Self>
where Rhs: ?Sized,
{ // Required method fn eq(&self, other: &Rhs) -> bool; // Provided method fn ne(&self, other: &Rhs) -> bool { ... } }
Trait for comparisons using the equality operator.

Implementing this trait for types provides the == and != operators for those types.

x.eq(y) can also be written x == y, and x.ne(y) can be written x != y. We use the easier-to-read infix notation in the remainder of this documentation.

This trait allows for comparisons using the equality operator, for types that do not have a full equivalence relation. For example, in floating point numbers NaN != NaN, so floating point types implement PartialEq but not Eq. Formally speaking, when Rhs == Self, this trait corresponds to a partial equivalence relation.

Implementations must ensure that eq and ne are consistent with each other:

  • a != b if and only if !(a == b).

The default implementation of ne provides this consistency and is almost always sufficient. It should not be overridden without very good reason.

If PartialOrd or Ord are also implemented for Self and Rhs, their methods must also be consistent with PartialEq (see the documentation of those traits for the exact requirements). It’s easy to accidentally make them disagree by deriving some of the traits and manually implementing others.

The equality relation == must satisfy the following conditions (for all a, b, c of type A, B, C):

  • Symmetry: if A: PartialEq<B> and B: PartialEq<A>, then a == b implies b == a; and

  • Transitivity: if A: PartialEq<B> and B: PartialEq<C> and A: PartialEq<C>, then a == b and b == c implies a == c. This must also work for longer chains, such as when A: PartialEq<B>, B: PartialEq<C>, C: PartialEq<D>, and A: PartialEq<D> all exist.

Note that the B: PartialEq<A> (symmetric) and A: PartialEq<C> (transitive) impls are not forced to exist, but these requirements apply whenever they do exist.

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Cross-crate considerations

Upholding the requirements stated above can become tricky when one crate implements PartialEq for a type of another crate (i.e., to allow comparing one of its own types with a type from the standard library). The recommendation is to never implement this trait for a foreign type. In other words, such a crate should do impl PartialEq<ForeignType> for LocalType, but it should not do impl PartialEq<LocalType> for ForeignType.

This avoids the problem of transitive chains that criss-cross crate boundaries: for all local types T, you may assume that no other crate will add impls that allow comparing T == U. In other words, if other crates add impls that allow building longer transitive chains U1 == ... == T == V1 == ..., then all the types that appear to the right of T must be types that the crate defining T already knows about. This rules out transitive chains where downstream crates can add new impls that “stitch together” comparisons of foreign types in ways that violate transitivity.

Not having such foreign impls also avoids forward compatibility issues where one crate adding more PartialEq implementations can cause build failures in downstream crates.

Derivable

This trait can be used with #[derive]. When derived on structs, two instances are equal if all fields are equal, and not equal if any fields are not equal. When derived on enums, two instances are equal if they are the same variant and all fields are equal.

How can I implement PartialEq?

An example implementation for a domain in which two books are considered the same book if their ISBN matches, even if the formats differ:

enum BookFormat {
    Paperback,
    Hardback,
    Ebook,
}

struct Book {
    isbn: i32,
    format: BookFormat,
}

impl PartialEq for Book {
    fn eq(&self, other: &Self) -> bool {
        self.isbn == other.isbn
    }
}

let b1 = Book { isbn: 3, format: BookFormat::Paperback };
let b2 = Book { isbn: 3, format: BookFormat::Ebook };
let b3 = Book { isbn: 10, format: BookFormat::Paperback };

assert!(b1 == b2);
assert!(b1 != b3);

How can I compare two different types?

The type you can compare with is controlled by PartialEq’s type parameter. For example, let’s tweak our previous code a bit:

// The derive implements <BookFormat> == <BookFormat> comparisons
#[derive(PartialEq)]
enum BookFormat {
    Paperback,
    Hardback,
    Ebook,
}

struct Book {
    isbn: i32,
    format: BookFormat,
}

// Implement <Book> == <BookFormat> comparisons
impl PartialEq<BookFormat> for Book {
    fn eq(&self, other: &BookFormat) -> bool {
        self.format == *other
    }
}

// Implement <BookFormat> == <Book> comparisons
impl PartialEq<Book> for BookFormat {
    fn eq(&self, other: &Book) -> bool {
        *self == other.format
    }
}

let b1 = Book { isbn: 3, format: BookFormat::Paperback };

assert!(b1 == BookFormat::Paperback);
assert!(BookFormat::Ebook != b1);

By changing impl PartialEq for Book to impl PartialEq<BookFormat> for Book, we allow BookFormats to be compared with Books.

A comparison like the one above, which ignores some fields of the struct, can be dangerous. It can easily lead to an unintended violation of the requirements for a partial equivalence relation. For example, if we kept the above implementation of PartialEq<Book> for BookFormat and added an implementation of PartialEq<Book> for Book (either via a #[derive] or via the manual implementation from the first example) then the result would violate transitivity:

#[derive(PartialEq)]
enum BookFormat {
    Paperback,
    Hardback,
    Ebook,
}

#[derive(PartialEq)]
struct Book {
    isbn: i32,
    format: BookFormat,
}

impl PartialEq<BookFormat> for Book {
    fn eq(&self, other: &BookFormat) -> bool {
        self.format == *other
    }
}

impl PartialEq<Book> for BookFormat {
    fn eq(&self, other: &Book) -> bool {
        *self == other.format
    }
}

fn main() {
    let b1 = Book { isbn: 1, format: BookFormat::Paperback };
    let b2 = Book { isbn: 2, format: BookFormat::Paperback };

    assert!(b1 == BookFormat::Paperback);
    assert!(BookFormat::Paperback == b2);

    // The following should hold by transitivity but doesn't.
    assert!(b1 == b2); // <-- PANICS
}

Examples

let x: u32 = 0;
let y: u32 = 1;

assert_eq!(x == y, false);
assert_eq!(x.eq(&y), false);

Required Methods

1.0.0 · Source

fn eq(&self, other: &Rhs) -> bool

Tests for self and other values to be equal, and is used by ==.

Provided Methods

1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.

Implementors

Source

impl PartialEq for DecodeError

Source

impl PartialEq for hashbrown::TryReserveError

Source

impl PartialEq for hashbrown::TryReserveError

Source

impl PartialEq for indexmap::GetDisjointMutError

Source

impl PartialEq for Level

Source

impl PartialEq for LevelFilter

Source

impl PartialEq for AddressSize

Source

impl PartialEq for object::common::Architecture

Source

impl PartialEq for object::common::BinaryFormat

Source

impl PartialEq for ComdatKind

Source

impl PartialEq for FileFlags

Source

impl PartialEq for RelocationEncoding

Source

impl PartialEq for RelocationFlags

Source

impl PartialEq for RelocationKind

Source

impl PartialEq for SectionFlags

Source

impl PartialEq for SectionKind

Source

impl PartialEq for object::common::SegmentFlags

Source

impl PartialEq for SubArchitecture

Source

impl PartialEq for SymbolKind

Source

impl PartialEq for SymbolScope

Source

impl PartialEq for object::endian::Endianness

Source

impl PartialEq for ArchiveKind

Source

impl PartialEq for ImportType

Source

impl PartialEq for CompressionFormat

Source

impl PartialEq for FileKind

Source

impl PartialEq for ObjectKind

Source

impl PartialEq for object::read::RelocationTarget

Source

impl PartialEq for object::read::SymbolSection

Source

impl PartialEq for CoffExportStyle

Source

impl PartialEq for Mangling

Source

impl PartialEq for StandardSection

Source

impl PartialEq for StandardSegment

Source

impl PartialEq for object::write::SymbolSection

Source

impl PartialEq for postcard::error::Error

Source

impl PartialEq for CDataModel

Source

impl PartialEq for Size

Source

impl PartialEq for ParseError

Source

impl PartialEq for Aarch64Architecture

Source

impl PartialEq for target_lexicon::targets::Architecture

Source

impl PartialEq for ArmArchitecture

Source

impl PartialEq for target_lexicon::targets::BinaryFormat

Source

impl PartialEq for CustomVendor

Source

impl PartialEq for Environment

Source

impl PartialEq for Mips32Architecture

Source

impl PartialEq for Mips64Architecture

Source

impl PartialEq for OperatingSystem

Source

impl PartialEq for Riscv32Architecture

Source

impl PartialEq for Riscv64Architecture

Source

impl PartialEq for target_lexicon::targets::Vendor

Source

impl PartialEq for X86_32Architecture

Source

impl PartialEq for CallingConvention

Source

impl PartialEq for target_lexicon::triple::Endianness

Source

impl PartialEq for PointerWidth

Source

impl PartialEq for zerocopy::byteorder::BigEndian

Source

impl PartialEq for zerocopy::byteorder::LittleEndian

Source

impl PartialEq for ConstOp

Source

impl PartialEq for EngineOrModuleTypeIndex

Source

impl PartialEq for EntityIndex

Source

impl PartialEq for wasmtime_environ::RelocationTarget

Source

impl PartialEq for Trap

Source

impl PartialEq for VMGcKind

Source

impl PartialEq for WasmCompositeType

Source

impl PartialEq for WasmHeapTopType

Source

impl PartialEq for WasmHeapType

Source

impl PartialEq for WasmStorageType

Source

impl PartialEq for WasmValType

Source

impl PartialEq for LibCall



impl PartialEq for AbstractHeapType



impl PartialEq for BlockType



impl PartialEq for CanonicalFunction



impl PartialEq for CanonicalOption



impl PartialEq for Catch



impl PartialEq for ComdatSymbolKind



impl PartialEq for ComponentExternalKind



impl PartialEq for ComponentOuterAliasKind



impl PartialEq for ComponentTypeRef



impl PartialEq for ComponentValType



impl PartialEq for CompositeInnerType



impl PartialEq for wasmtime_environ::wasmparser::Encoding



impl PartialEq for ExternalKind



impl PartialEq for FrameKind



impl PartialEq for HeapType



impl PartialEq for InstantiationArgKind



impl PartialEq for wasmtime_environ::wasmparser::Ordering



impl PartialEq for OuterAliasKind



impl PartialEq for PrimitiveValType



impl PartialEq for RelocAddendKind



impl PartialEq for RelocationType



impl PartialEq for StorageType



impl PartialEq for TagKind



impl PartialEq for TypeBounds



impl PartialEq for TypeRef



impl PartialEq for UnpackedIndex



impl PartialEq for ValType



impl PartialEq for ComponentNameKind<'_>



impl PartialEq for AnyTypeId



impl PartialEq for ComponentAnyTypeId



impl PartialEq for ComponentCoreTypeId

Source

impl PartialEq for AsciiChar

1.0.0 (const: unstable) · Source

impl PartialEq for wasmtime_environ::__core::cmp::Ordering

1.34.0 (const: unstable) · Source

impl PartialEq for Infallible

1.64.0 · Source

impl PartialEq for FromBytesWithNulError

1.28.0 · Source

impl PartialEq for wasmtime_environ::__core::fmt::Alignment

Source

impl PartialEq for DebugAsHex

Source

impl PartialEq for Sign

Source

impl PartialEq for Locality

Source

impl PartialEq for AtomicOrdering

Source

impl PartialEq for SimdAlign

1.7.0 · Source

impl PartialEq for IpAddr

Source

impl PartialEq for Ipv6MulticastScope

1.0.0 · Source

impl PartialEq for SocketAddr

1.0.0 · Source

impl PartialEq for FpCategory

1.55.0 · Source

impl PartialEq for IntErrorKind

1.86.0 · Source

impl PartialEq for wasmtime_environ::__core::slice::GetDisjointMutError

Source

impl PartialEq for SearchStep

1.0.0 · Source

impl PartialEq for wasmtime_environ::__core::sync::atomic::Ordering

Source

impl PartialEq for alloc::collections::TryReserveErrorKind

1.65.0 · Source

impl PartialEq for BacktraceStatus

1.0.0 · Source

impl PartialEq for VarError

1.0.0 · Source

impl PartialEq for SeekFrom

1.0.0 · Source

impl PartialEq for ErrorKind

1.0.0 · Source

impl PartialEq for Shutdown

Source

impl PartialEq for BacktraceStyle

1.12.0 · Source

impl PartialEq for RecvTimeoutError

1.0.0 · Source

impl PartialEq for TryRecvError

Source

impl PartialEq for Op

1.0.0 (const: unstable) · Source

impl PartialEq for bool

1.0.0 (const: unstable) · Source

impl PartialEq for char

1.0.0 (const: unstable) · Source

impl PartialEq for f16

1.0.0 (const: unstable) · Source

impl PartialEq for f32

1.0.0 (const: unstable) · Source

impl PartialEq for f64

1.0.0 (const: unstable) · Source

impl PartialEq for f128

1.0.0 (const: unstable) · Source

impl PartialEq for i8

1.0.0 (const: unstable) · Source

impl PartialEq for i16

1.0.0 (const: unstable) · Source

impl PartialEq for i32

1.0.0 (const: unstable) · Source

impl PartialEq for i64

1.0.0 (const: unstable) · Source

impl PartialEq for i128

1.0.0 (const: unstable) · Source

impl PartialEq for isize

Source

impl PartialEq for !

1.0.0 (const: unstable) · Source

impl PartialEq for str

1.0.0 (const: unstable) · Source

impl PartialEq for u8

1.0.0 (const: unstable) · Source

impl PartialEq for u16

1.0.0 (const: unstable) · Source

impl PartialEq for u32

1.0.0 (const: unstable) · Source

impl PartialEq for u64

1.0.0 (const: unstable) · Source

impl PartialEq for u128

1.0.0 (const: unstable) · Source

impl PartialEq for ()

1.0.0 (const: unstable) · Source

impl PartialEq for usize

Source

impl PartialEq for DestBufTooSmallError

Source

impl PartialEq for CompoundBitSet

Source

impl PartialEq for getrandom::error::Error

Source

impl PartialEq for indexmap::TryReserveError

Source

impl PartialEq for ParseLevelError

Source

impl PartialEq for object::endian::BigEndian

Source

impl PartialEq for object::endian::LittleEndian

Source

impl PartialEq for Guid

Source

impl PartialEq for CompressedFileRange

Source

impl PartialEq for object::read::Error

Source

impl PartialEq for object::read::SectionIndex

Source

impl PartialEq for object::read::SymbolIndex

Source

impl PartialEq for Class

Source

impl PartialEq for object::write::elf::writer::SectionIndex

Source

impl PartialEq for object::write::elf::writer::SymbolIndex

Source

impl PartialEq for object::write::string::StringId

Source

impl PartialEq for ComdatId

Source

impl PartialEq for object::write::Error

Source

impl PartialEq for object::write::SectionId

Source

impl PartialEq for SymbolId

Source

impl PartialEq for IgnoredAny

Source

impl PartialEq for serde_core::de::value::Error

Source

impl PartialEq for DefaultToHost

Source

impl PartialEq for DefaultToUnknown

Source

impl PartialEq for Triple

Source

impl PartialEq for zerocopy::error::AllocError

1.0.0 · Source

impl PartialEq for String

Source

impl PartialEq for BuiltinFunctionIndex

Source

impl PartialEq for wasmtime_environ::ConstExpr

Source

impl PartialEq for DataIndex

Source

impl PartialEq for DefinedFuncIndex

Source

impl PartialEq for DefinedGlobalIndex

Source

impl PartialEq for DefinedMemoryIndex

Source

impl PartialEq for DefinedTableIndex

Source

impl PartialEq for ElemIndex

Source

impl PartialEq for EngineInternedRecGroupIndex

Source

impl PartialEq for FilePos

Source

impl PartialEq for FuncIndex

Source

impl PartialEq for FuncRefIndex

Source

impl PartialEq for Global

Source

impl PartialEq for GlobalIndex

Source

impl PartialEq for InstructionAddressMap

Source

impl PartialEq for Memory

Source

impl PartialEq for MemoryIndex

Source

impl PartialEq for ModuleInternedRecGroupIndex

Source

impl PartialEq for ModuleInternedTypeIndex

Source

impl PartialEq for OwnedMemoryIndex

Source

impl PartialEq for RecGroupRelativeTypeIndex

Source

impl PartialEq for StaticModuleIndex

Source

impl PartialEq for Table

Source

impl PartialEq for TableIndex

Source

impl PartialEq for Tag

Source

impl PartialEq for TagIndex

Source

impl PartialEq for TrapInformation

Source

impl PartialEq for TypeIndex

Source

impl PartialEq for VMSharedTypeIndex

Source

impl PartialEq for WasmArrayType

Source

impl PartialEq for WasmFieldType

Source

impl PartialEq for WasmFuncType

Source

impl PartialEq for WasmRecGroup

Source

impl PartialEq for WasmRefType

Source

impl PartialEq for WasmStructType

Source

impl PartialEq for WasmSubType



impl PartialEq for ComponentName



impl PartialEq for KebabStr



impl PartialEq for KebabString



impl PartialEq for ArrayType



impl PartialEq for BrTable<'_>



impl PartialEq for CompositeType



impl PartialEq for wasmtime_environ::wasmparser::ConstExpr<'_>



impl PartialEq for FieldType



impl PartialEq for FuncType



impl PartialEq for GlobalType



impl PartialEq for Ieee32



impl PartialEq for Ieee64



impl PartialEq for MemArg



impl PartialEq for MemoryType



impl PartialEq for PackedIndex



impl PartialEq for RecGroup



impl PartialEq for RefType



impl PartialEq for RelocationEntry



impl PartialEq for wasmtime_environ::wasmparser::SegmentFlags



impl PartialEq for StructType



impl PartialEq for SubType



impl PartialEq for wasmtime_environ::wasmparser::SymbolFlags



impl PartialEq for TableType



impl PartialEq for TagType



impl PartialEq for TryTable



impl PartialEq for V128



impl PartialEq for ValidatorId



impl PartialEq for WasmFeatures



impl PartialEq for AliasableResourceId



impl PartialEq for ComponentCoreInstanceTypeId



impl PartialEq for ComponentCoreModuleTypeId



impl PartialEq for ComponentDefinedTypeId



impl PartialEq for ComponentFuncTypeId



impl PartialEq for ComponentInstanceTypeId



impl PartialEq for ComponentTypeId



impl PartialEq for ComponentValueTypeId



impl PartialEq for CoreTypeId



impl PartialEq for RecGroupId



impl PartialEq for ResourceId

Source

impl PartialEq for wasmtime_environ::__core::alloc::AllocError

1.28.0 · Source

impl PartialEq for Layout

1.50.0 · Source

impl PartialEq for LayoutError

1.0.0 (const: unstable) · Source

impl PartialEq for TypeId

1.27.0 · Source

impl PartialEq for CpuidResult

Source

impl PartialEq for ByteStr

1.34.0 · Source

impl PartialEq for CharTryFromError

1.9.0 · Source

impl PartialEq for DecodeUtf16Error

1.20.0 · Source

impl PartialEq for ParseCharError

1.59.0 · Source

impl PartialEq for TryFromCharError

1.64.0 · Source

impl PartialEq for CStr

1.69.0 · Source

impl PartialEq for FromBytesUntilNulError

1.0.0 · Source

impl PartialEq for wasmtime_environ::__core::fmt::Error

Source

impl PartialEq for FormattingOptions

1.33.0 · Source

impl PartialEq for PhantomPinned

Source

impl PartialEq for Assume

1.0.0 · Source

impl PartialEq for AddrParseError

1.0.0 · Source

impl PartialEq for Ipv4Addr

1.0.0 · Source

impl PartialEq for Ipv6Addr

1.0.0 · Source

impl PartialEq for SocketAddrV4

1.0.0 · Source

impl PartialEq for SocketAddrV6

1.0.0 · Source

impl PartialEq for ParseFloatError

1.0.0 · Source

impl PartialEq for ParseIntError

1.34.0 · Source

impl PartialEq for TryFromIntError

1.0.0 (const: unstable) · Source

impl PartialEq for RangeFull

1.10.0 · Source

impl PartialEq for wasmtime_environ::__core::panic::Location<'_>

Source

impl PartialEq for wasmtime_environ::__core::ptr::Alignment

1.0.0 · Source

impl PartialEq for ParseBoolError

1.0.0 · Source

impl PartialEq for Utf8Error

1.36.0 · Source

impl PartialEq for RawWaker

1.36.0 · Source

impl PartialEq for RawWakerVTable

1.3.0 · Source

impl PartialEq for Duration

1.66.0 · Source

impl PartialEq for TryFromFloatSecsError

Source

impl PartialEq for ByteString

Source

impl PartialEq for UnorderedKeyError

1.57.0 · Source

impl PartialEq for alloc::collections::TryReserveError

1.64.0 · Source

impl PartialEq for CString

1.64.0 · Source

impl PartialEq for FromVecWithNulError

1.64.0 · Source

impl PartialEq for IntoStringError

1.64.0 · Source

impl PartialEq for NulError

1.0.0 · Source

impl PartialEq for FromUtf8Error

1.0.0 · Source

impl PartialEq for OsStr

1.0.0 · Source

impl PartialEq for OsString

1.1.0 · Source

impl PartialEq for FileType

1.0.0 · Source

impl PartialEq for Permissions

Source

impl PartialEq for UCred

Source

impl PartialEq for NormalizeError

1.0.0 · Source

impl PartialEq for Path

1.0.0 · Source

impl PartialEq for PathBuf

1.7.0 · Source

impl PartialEq for StripPrefixError

1.61.0 · Source

impl PartialEq for ExitCode

1.0.0 · Source

impl PartialEq for ExitStatus

Source

impl PartialEq for ExitStatusError

1.0.0 · Source

impl PartialEq for Output

1.0.0 · Source

impl PartialEq for RecvError

1.5.0 · Source

impl PartialEq for WaitTimeoutResult

1.19.0 · Source

impl PartialEq for ThreadId

1.26.0 · Source

impl PartialEq for AccessError

1.8.0 · Source

impl PartialEq for Instant

1.8.0 · Source

impl PartialEq for SystemTime

Source

impl PartialEq for BuildMetadata

Source

impl PartialEq for Comparator

Source

impl PartialEq for Prerelease

Source

impl PartialEq for Version

Source

impl PartialEq for VersionReq



impl PartialEq for Abbreviation



impl PartialEq for AbbreviationsCacheStrategy



impl PartialEq for Address



impl PartialEq for AllocError



impl PartialEq for ArangeEntry



impl PartialEq for Attribute



impl PartialEq for AttributeSpecification



impl PartialEq for AttributeValue



impl PartialEq for Augmentation



impl PartialEq for BaseAddresses



impl PartialEq for BigEndian



impl PartialEq for CallFrameInstruction



impl PartialEq for CieId



impl PartialEq for ColumnType



impl PartialEq for CommonInformationEntry



impl PartialEq for ConvertError



impl PartialEq for DebugTypeSignature



impl PartialEq for DirectoryId



impl PartialEq for DwAccess



impl PartialEq for DwAddr



impl PartialEq for DwAt



impl PartialEq for DwAte



impl PartialEq for DwCc



impl PartialEq for DwCfa



impl PartialEq for DwChildren



impl PartialEq for DwDefaulted



impl PartialEq for DwDs



impl PartialEq for DwDsc



impl PartialEq for DwEhPe



impl PartialEq for DwEnd



impl PartialEq for DwForm



impl PartialEq for DwId



impl PartialEq for DwIdx



impl PartialEq for DwInl



impl PartialEq for DwLang



impl PartialEq for DwLle



impl PartialEq for DwLnct



impl PartialEq for DwLne



impl PartialEq for DwLns



impl PartialEq for DwMacro



impl PartialEq for DwOp



impl PartialEq for DwOrd



impl PartialEq for DwRle



impl PartialEq for DwSect



impl PartialEq for DwSectV2



impl PartialEq for DwTag



impl PartialEq for DwUt



impl PartialEq for DwVirtuality



impl PartialEq for DwVis



impl PartialEq for DwarfFileType



impl PartialEq for DwoId



impl PartialEq for Encoding



impl PartialEq for Error



impl PartialEq for Error



impl PartialEq for Expression



impl PartialEq for FileEntryFormat



impl PartialEq for FileId



impl PartialEq for FileInfo



impl PartialEq for Format



impl PartialEq for FrameDescriptionEntry



impl PartialEq for LineEncoding



impl PartialEq for LineRow



impl PartialEq for LineString



impl PartialEq for LineStringId



impl PartialEq for LittleEndian



impl PartialEq for Location



impl PartialEq for LocationList



impl PartialEq for LocationListId



impl PartialEq for Pointer



impl PartialEq for Range



impl PartialEq for Range



impl PartialEq for RangeList



impl PartialEq for RangeListId



impl PartialEq for ReaderOffsetId



impl PartialEq for Reference



impl PartialEq for Register



impl PartialEq for Relocation



impl PartialEq for RelocationTarget



impl PartialEq for RunTimeEndian



impl PartialEq for SectionBaseAddresses



impl PartialEq for SectionId



impl PartialEq for StoreOnHeap



impl PartialEq for StringId



impl PartialEq for TryReserveError



impl PartialEq for TryReserveErrorKind



impl PartialEq for UnitEntryId



impl PartialEq for UnitId



impl PartialEq for UnitIndexSection



impl PartialEq for Value



impl PartialEq for ValueType



impl PartialEq for Vendor

1.0.0 · Source

impl PartialEq<&str> for Cow<'_, str>

1.0.0 · Source

impl PartialEq<&str> for String

Source

impl PartialEq<&str> for ByteStr

Source

impl PartialEq<&str> for ByteString

1.29.0 · Source

impl PartialEq<&str> for OsString

Source

impl PartialEq<&ByteStr> for Cow<'_, str>

Source

impl PartialEq<&ByteStr> for Cow<'_, ByteStr>

Source

impl PartialEq<&ByteStr> for Cow<'_, [u8]>

Source

impl PartialEq<&ByteStr> for ByteString

1.90.0 · Source

impl PartialEq<&CStr> for Cow<'_, CStr>

Available on non-no_global_oom_handling only.
1.90.0 · Source

impl PartialEq<&CStr> for CStr

1.90.0 · Source

impl PartialEq<&CStr> for CString

1.8.0 · Source

impl PartialEq<&OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialEq<&OsStr> for Cow<'_, Path>

1.8.0 · Source

impl PartialEq<&OsStr> for OsString

1.8.0 · Source

impl PartialEq<&OsStr> for Path

1.8.0 · Source

impl PartialEq<&OsStr> for PathBuf

1.8.0 · Source

impl PartialEq<&Path> for Cow<'_, OsStr>

1.6.0 · Source

impl PartialEq<&Path> for Cow<'_, Path>

1.8.0 · Source

impl PartialEq<&Path> for OsStr

1.8.0 · Source

impl PartialEq<&Path> for OsString

1.6.0 · Source

impl PartialEq<&Path> for PathBuf

Source

impl PartialEq<&[u8]> for ByteStr

Source

impl PartialEq<&[u8]> for ByteString

Source

impl PartialEq<Level> for LevelFilter

Source

impl PartialEq<LevelFilter> for Level

1.16.0 · Source

impl PartialEq<IpAddr> for Ipv4Addr

1.16.0 · Source

impl PartialEq<IpAddr> for Ipv6Addr

1.0.0 · Source

impl PartialEq<Cow<'_, str>> for &str

Source

impl PartialEq<Cow<'_, str>> for &ByteStr

1.0.0 · Source

impl PartialEq<Cow<'_, str>> for str

1.0.0 · Source

impl PartialEq<Cow<'_, str>> for String

Source

impl PartialEq<Cow<'_, str>> for ByteString

Source

impl PartialEq<Cow<'_, ByteStr>> for &ByteStr

Source

impl PartialEq<Cow<'_, ByteStr>> for ByteString

1.90.0 · Source

impl PartialEq<Cow<'_, CStr>> for CStr

Available on non-no_global_oom_handling only.
1.90.0 · Source

impl PartialEq<Cow<'_, CStr>> for CString

Available on non-no_global_oom_handling only.
1.8.0 · Source

impl PartialEq<Cow<'_, OsStr>> for &OsStr

1.8.0 · Source

impl PartialEq<Cow<'_, OsStr>> for &Path

1.8.0 · Source

impl PartialEq<Cow<'_, OsStr>> for OsStr

1.8.0 · Source

impl PartialEq<Cow<'_, OsStr>> for OsString

1.8.0 · Source

impl PartialEq<Cow<'_, OsStr>> for Path

1.8.0 · Source

impl PartialEq<Cow<'_, OsStr>> for PathBuf

1.8.0 · Source

impl PartialEq<Cow<'_, Path>> for &OsStr

1.6.0 · Source

impl PartialEq<Cow<'_, Path>> for &Path

1.8.0 · Source

impl PartialEq<Cow<'_, Path>> for OsStr

1.8.0 · Source

impl PartialEq<Cow<'_, Path>> for OsString

1.6.0 · Source

impl PartialEq<Cow<'_, Path>> for Path

1.6.0 · Source

impl PartialEq<Cow<'_, Path>> for PathBuf

Source

impl PartialEq<Cow<'_, [u8]>> for &ByteStr

Source

impl PartialEq<Cow<'_, [u8]>> for ByteString

1.0.0 · Source

impl PartialEq<str> for Cow<'_, str>

1.0.0 · Source

impl PartialEq<str> for String

Source

impl PartialEq<str> for ByteStr

Source

impl PartialEq<str> for ByteString

1.0.0 · Source

impl PartialEq<str> for OsStr

1.0.0 · Source

impl PartialEq<str> for OsString

1.91.0 · Source

impl PartialEq<str> for Path

1.91.0 · Source

impl PartialEq<str> for PathBuf

1.0.0 · Source

impl PartialEq<String> for &str

1.0.0 · Source

impl PartialEq<String> for Cow<'_, str>

1.0.0 · Source

impl PartialEq<String> for str

Source

impl PartialEq<String> for ByteStr

Source

impl PartialEq<String> for ByteString

1.91.0 · Source

impl PartialEq<String> for Path

1.91.0 · Source

impl PartialEq<String> for PathBuf

Source

impl PartialEq<Vec<u8>> for ByteStr

Source

impl PartialEq<Vec<u8>> for ByteString



impl PartialEq<KebabStr> for KebabString



impl PartialEq<KebabString> for KebabStr

Source

impl PartialEq<ByteStr> for &str

Source

impl PartialEq<ByteStr> for &[u8]

Source

impl PartialEq<ByteStr> for str

Source

impl PartialEq<ByteStr> for String

Source

impl PartialEq<ByteStr> for wasmtime_environ::prelude::Vec<u8>

Source

impl PartialEq<ByteStr> for ByteString

Source

impl PartialEq<ByteStr> for [u8]

1.90.0 · Source

impl PartialEq<CStr> for Cow<'_, CStr>

Available on non-no_global_oom_handling only.
1.90.0 · Source

impl PartialEq<CStr> for CString

1.16.0 · Source

impl PartialEq<Ipv4Addr> for IpAddr

1.16.0 · Source

impl PartialEq<Ipv6Addr> for IpAddr

Source

impl PartialEq<ByteString> for &str

Source

impl PartialEq<ByteString> for &ByteStr

Source

impl PartialEq<ByteString> for &[u8]

Source

impl PartialEq<ByteString> for Cow<'_, str>

Source

impl PartialEq<ByteString> for Cow<'_, ByteStr>

Source

impl PartialEq<ByteString> for Cow<'_, [u8]>

Source

impl PartialEq<ByteString> for str

Source

impl PartialEq<ByteString> for String

Source

impl PartialEq<ByteString> for wasmtime_environ::prelude::Vec<u8>

Source

impl PartialEq<ByteString> for ByteStr

Source

impl PartialEq<ByteString> for [u8]

1.90.0 · Source

impl PartialEq<CString> for Cow<'_, CStr>

Available on non-no_global_oom_handling only.
1.90.0 · Source

impl PartialEq<CString> for CStr

1.8.0 · Source

impl PartialEq<OsStr> for &Path

1.8.0 · Source

impl PartialEq<OsStr> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialEq<OsStr> for Cow<'_, Path>

1.0.0 · Source

impl PartialEq<OsStr> for str

1.8.0 · Source

impl PartialEq<OsStr> for OsString

1.8.0 · Source

impl PartialEq<OsStr> for Path

1.8.0 · Source

impl PartialEq<OsStr> for PathBuf

1.8.0 · Source

impl PartialEq<OsString> for &OsStr

1.8.0 · Source

impl PartialEq<OsString> for &Path

1.8.0 · Source

impl PartialEq<OsString> for Cow<'_, OsStr>

1.8.0 · Source

impl PartialEq<OsString> for Cow<'_, Path>

1.0.0 · Source

impl PartialEq<OsString> for str

1.8.0 · Source

impl PartialEq<OsString> for OsStr

1.8.0 · Source

impl PartialEq<OsString> for Path

1.8.0 · Source

impl PartialEq<OsString> for PathBuf

1.8.0 · Source

impl PartialEq<Path> for &OsStr

1.8.0 · Source

impl PartialEq<Path> for Cow<'_, OsStr>

1.6.0 · Source

impl PartialEq<Path> for Cow<'_, Path>

1.91.0 · Source

impl PartialEq<Path> for str

1.91.0 · Source

impl PartialEq<Path> for String

1.8.0 · Source

impl PartialEq<Path> for OsStr

1.8.0 · Source

impl PartialEq<Path> for OsString

1.6.0 · Source

impl PartialEq<Path> for PathBuf

1.8.0 · Source

impl PartialEq<PathBuf> for &OsStr

1.6.0 · Source

impl PartialEq<PathBuf> for &Path

1.8.0 · Source

impl PartialEq<PathBuf> for Cow<'_, OsStr>

1.6.0 · Source

impl PartialEq<PathBuf> for Cow<'_, Path>

1.91.0 · Source

impl PartialEq<PathBuf> for str

1.91.0 · Source

impl PartialEq<PathBuf> for String

1.8.0 · Source

impl PartialEq<PathBuf> for OsStr

1.8.0 · Source

impl PartialEq<PathBuf> for OsString

1.6.0 · Source

impl PartialEq<PathBuf> for Path

Source

impl PartialEq<[u8]> for ByteStr

Source

impl PartialEq<[u8]> for ByteString

Source

impl<'a> PartialEq for Unexpected<'a>

Source

impl<'a> PartialEq for FlagValue<'a>



impl<'a> PartialEq for ComponentAlias<'a>



impl<'a> PartialEq for ComponentDefinedType<'a>



impl<'a> PartialEq for ComponentFuncResult<'a>



impl<'a> PartialEq for ComponentInstance<'a>



impl<'a> PartialEq for ComponentType<'a>



impl<'a> PartialEq for ComponentTypeDeclaration<'a>



impl<'a> PartialEq for CoreType<'a>



impl<'a> PartialEq for Instance<'a>



impl<'a> PartialEq for InstanceTypeDeclaration<'a>



impl<'a> PartialEq for ModuleTypeDeclaration<'a>



impl<'a> PartialEq for Operator<'a>

Source

impl<'a> PartialEq for Utf8Pattern<'a>

1.0.0 · Source

impl<'a> PartialEq for Component<'a>

1.0.0 · Source

impl<'a> PartialEq for Prefix<'a>

Source

impl<'a> PartialEq for Metadata<'a>

Source

impl<'a> PartialEq for MetadataBuilder<'a>



impl<'a> PartialEq for DependencyName<'a>



impl<'a> PartialEq for HashName<'a>



impl<'a> PartialEq for InterfaceName<'a>



impl<'a> PartialEq for ResourceFunc<'a>



impl<'a> PartialEq for UrlName<'a>



impl<'a> PartialEq for ComponentExport<'a>



impl<'a> PartialEq for ComponentExportName<'a>



impl<'a> PartialEq for ComponentFuncType<'a>



impl<'a> PartialEq for ComponentImport<'a>



impl<'a> PartialEq for ComponentImportName<'a>



impl<'a> PartialEq for ComponentInstantiationArg<'a>



impl<'a> PartialEq for wasmtime_environ::wasmparser::Export<'a>



impl<'a> PartialEq for wasmtime_environ::wasmparser::Import<'a>



impl<'a> PartialEq for InstantiationArg<'a>



impl<'a> PartialEq for VariantCase<'a>

Source

impl<'a> PartialEq for PhantomContravariantLifetime<'a>

Source

impl<'a> PartialEq for PhantomCovariantLifetime<'a>

Source

impl<'a> PartialEq for PhantomInvariantLifetime<'a>

1.79.0 · Source

impl<'a> PartialEq for Utf8Chunk<'a>

1.0.0 · Source

impl<'a> PartialEq for Components<'a>

1.0.0 · Source

impl<'a> PartialEq for PrefixComponent<'a>

1.29.0 · Source

impl<'a> PartialEq<OsString> for &'a str

1.0.0 · Source

impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
where B: PartialEq<C> + ToOwned + ?Sized, C: ToOwned + ?Sized,



impl<'bases, Section, R> PartialEq for CieOrFde<'bases, Section, R>
where Section: PartialEq + UnwindSection<R>, R: PartialEq + Reader,



impl<'bases, Section, R> PartialEq for PartialFrameDescriptionEntry<'bases, Section, R>
where Section: PartialEq + UnwindSection<R>, R: PartialEq + Reader, <R as Reader>::Offset: PartialEq, <Section as UnwindSection<R>>::Offset: PartialEq,

Source

impl<'data> PartialEq for ImportName<'data>

Source

impl<'data> PartialEq for CodeView<'data>

Source

impl<'data> PartialEq for CompressedData<'data>

Source

impl<'data> PartialEq for object::read::Export<'data>

Source

impl<'data> PartialEq for object::read::Import<'data>

Source

impl<'data> PartialEq for ObjectMapEntry<'data>

Source

impl<'data> PartialEq for ObjectMapFile<'data>

Source

impl<'data> PartialEq for SymbolMapName<'data>

Source

impl<'data> PartialEq for Bytes<'data>



impl<'input, Endian> PartialEq for EndianSlice<'input, Endian>
where Endian: PartialEq + Endianity,

1.0.0 (const: unstable) · Source

impl<A, B> PartialEq<&B> for &A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialEq<&B> for &mut A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialEq<&mut B> for &A
where A: PartialEq<B> + ?Sized, B: ?Sized,

1.0.0 (const: unstable) · Source

impl<A, B> PartialEq<&mut B> for &mut A
where A: PartialEq<B> + ?Sized, B: ?Sized,

Source

impl<A, B> PartialEq<SmallVec<B>> for SmallVec<A>
where A: Array, B: Array, <A as Array>::Item: PartialEq<<B as Array>::Item>,

Source

impl<A, S, V> PartialEq for zerocopy::error::ConvertError<A, S, V>
where A: PartialEq, S: PartialEq, V: PartialEq,

1.55.0 (const: unstable) · Source

impl<B, C> PartialEq for ControlFlow<B, C>
where B: PartialEq, C: PartialEq,

Source

impl<Dyn> PartialEq for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> PartialEq for I16Bytes<E>
where E: PartialEq + Endian,

Source

impl<E> PartialEq for I32Bytes<E>
where E: PartialEq + Endian,

Source

impl<E> PartialEq for I64Bytes<E>
where E: PartialEq + Endian,

Source

impl<E> PartialEq for U16Bytes<E>
where E: PartialEq + Endian,

Source

impl<E> PartialEq for U32Bytes<E>
where E: PartialEq + Endian,

Source

impl<E> PartialEq for U64Bytes<E>
where E: PartialEq + Endian,

1.4.0 · Source

impl<F> PartialEq for F
where F: FnPtr,

1.29.0 · Source

impl<H> PartialEq for BuildHasherDefault<H>

1.0.0 (const: unstable) · Source

impl<Idx> PartialEq for wasmtime_environ::__core::ops::Range<Idx>
where Idx: PartialEq,

1.0.0 (const: unstable) · Source

impl<Idx> PartialEq for wasmtime_environ::__core::ops::RangeFrom<Idx>
where Idx: PartialEq,

1.26.0 (const: unstable) · Source

impl<Idx> PartialEq for wasmtime_environ::__core::ops::RangeInclusive<Idx>
where Idx: PartialEq,

1.0.0 (const: unstable) · Source

impl<Idx> PartialEq for RangeTo<Idx>
where Idx: PartialEq,

1.26.0 · Source

impl<Idx> PartialEq for wasmtime_environ::__core::ops::RangeToInclusive<Idx>
where Idx: PartialEq,

Source

impl<Idx> PartialEq for wasmtime_environ::__core::range::Range<Idx>
where Idx: PartialEq,

Source

impl<Idx> PartialEq for wasmtime_environ::__core::range::RangeFrom<Idx>
where Idx: PartialEq,

1.95.0 · Source

impl<Idx> PartialEq for wasmtime_environ::__core::range::RangeInclusive<Idx>
where Idx: PartialEq,

Source

impl<Idx> PartialEq for wasmtime_environ::__core::range::RangeToInclusive<Idx>
where Idx: PartialEq,

Source

impl<K, V1, S1, V2, S2> PartialEq<IndexMap<K, V2, S2>> for indexmap::map::IndexMap<K, V1, S1>
where K: Hash + Eq, V1: PartialEq<V2>, S1: BuildHasher, S2: BuildHasher,



impl<K, V> PartialEq for wasmtime_environ::prelude::IndexMap<K, V>
where K: PartialEq + Hash + Ord, V: PartialEq,

Source

impl<K, V> PartialEq for PrimaryMap<K, V>
where K: PartialEq + EntityRef, V: PartialEq,

Source

impl<K, V> PartialEq for SecondaryMap<K, V>
where K: EntityRef, V: Clone + PartialEq,



impl<K, V> PartialEq for Map<K, V>
where K: Eq + Hash, V: Eq,

1.0.0 · Source

impl<K, V, A> PartialEq for BTreeMap<K, V, A>
where K: PartialEq, V: PartialEq, A: Allocator + Clone,

Source

impl<K, V, K2, V2> PartialEq<Slice<K2, V2>> for indexmap::map::slice::Slice<K, V>
where K: PartialEq<K2>, V: PartialEq<V2>,

Source

impl<K, V, K2, V2> PartialEq<Slice<K2, V2>> for [(K, V)]
where K: PartialEq<K2>, V: PartialEq<V2>,

Source

impl<K, V, K2, V2> PartialEq<[(K2, V2)]> for indexmap::map::slice::Slice<K, V>
where K: PartialEq<K2>, V: PartialEq<V2>,

Source

impl<K, V, K2, V2, const N: usize> PartialEq<[(K2, V2); N]> for indexmap::map::slice::Slice<K, V>
where K: PartialEq<K2>, V: PartialEq<V2>,

Source

impl<K, V, S> PartialEq for AHashMap<K, V, S>
where K: Eq + Hash, V: PartialEq, S: BuildHasher,

Source

impl<K, V, S, A> PartialEq for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash, V: PartialEq, S: BuildHasher, A: Allocator,

Source

impl<K, V, S, A> PartialEq for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash, V: PartialEq, S: BuildHasher, A: Allocator,

1.0.0 · Source

impl<K, V, S, A> PartialEq for std::collections::hash::map::HashMap<K, V, S, A>
where K: Eq + Hash, V: PartialEq, S: BuildHasher, A: Allocator,

Source

impl<K, V, const N: usize, K2, V2> PartialEq<Slice<K2, V2>> for [(K, V); N]
where K: PartialEq<K2>, V: PartialEq<V2>,

Source

impl<O> PartialEq for F32<O>
where O: PartialEq,

Source

impl<O> PartialEq for F64<O>
where O: PartialEq,

Source

impl<O> PartialEq for I16<O>
where O: PartialEq,

Source

impl<O> PartialEq for I32<O>
where O: PartialEq,

Source

impl<O> PartialEq for I64<O>
where O: PartialEq,

Source

impl<O> PartialEq for I128<O>
where O: PartialEq,

Source

impl<O> PartialEq for Isize<O>
where O: PartialEq,

Source

impl<O> PartialEq for U16<O>
where O: PartialEq,

Source

impl<O> PartialEq for U32<O>
where O: PartialEq,

Source

impl<O> PartialEq for U64<O>
where O: PartialEq,

Source

impl<O> PartialEq for U128<O>
where O: PartialEq,

Source

impl<O> PartialEq for Usize<O>
where O: PartialEq,

Source

impl<O> PartialEq<f32> for F32<O>
where O: ByteOrder,

Source

impl<O> PartialEq<f64> for F64<O>
where O: ByteOrder,

Source

impl<O> PartialEq<i16> for I16<O>
where O: ByteOrder,

Source

impl<O> PartialEq<i32> for I32<O>
where O: ByteOrder,

Source

impl<O> PartialEq<i64> for I64<O>
where O: ByteOrder,

Source

impl<O> PartialEq<i128> for I128<O>
where O: ByteOrder,

Source

impl<O> PartialEq<isize> for Isize<O>
where O: ByteOrder,

Source

impl<O> PartialEq<u16> for U16<O>
where O: ByteOrder,

Source

impl<O> PartialEq<u32> for U32<O>
where O: ByteOrder,

Source

impl<O> PartialEq<u64> for U64<O>
where O: ByteOrder,

Source

impl<O> PartialEq<u128> for U128<O>
where O: ByteOrder,

Source

impl<O> PartialEq<usize> for Usize<O>
where O: ByteOrder,

Source

impl<O> PartialEq<F32<O>> for [u8; 4]

Source

impl<O> PartialEq<F64<O>> for [u8; 8]

Source

impl<O> PartialEq<I16<O>> for [u8; 2]

Source

impl<O> PartialEq<I32<O>> for [u8; 4]

Source

impl<O> PartialEq<I64<O>> for [u8; 8]

Source

impl<O> PartialEq<I128<O>> for [u8; 16]

Source

impl<O> PartialEq<Isize<O>> for [u8; 8]

Source

impl<O> PartialEq<U16<O>> for [u8; 2]

Source

impl<O> PartialEq<U32<O>> for [u8; 4]

Source

impl<O> PartialEq<U64<O>> for [u8; 8]

Source

impl<O> PartialEq<U128<O>> for [u8; 16]

Source

impl<O> PartialEq<Usize<O>> for [u8; 8]

Source

impl<O> PartialEq<[u8; 2]> for I16<O>

Source

impl<O> PartialEq<[u8; 2]> for U16<O>

Source

impl<O> PartialEq<[u8; 4]> for F32<O>

Source

impl<O> PartialEq<[u8; 4]> for I32<O>

Source

impl<O> PartialEq<[u8; 4]> for U32<O>

Source

impl<O> PartialEq<[u8; 8]> for F64<O>

Source

impl<O> PartialEq<[u8; 8]> for I64<O>

Source

impl<O> PartialEq<[u8; 8]> for Isize<O>

Source

impl<O> PartialEq<[u8; 8]> for U64<O>

Source

impl<O> PartialEq<[u8; 8]> for Usize<O>

Source

impl<O> PartialEq<[u8; 16]> for I128<O>

Source

impl<O> PartialEq<[u8; 16]> for U128<O>



impl<Offset> PartialEq for UnitType<Offset>
where Offset: PartialEq + ReaderOffset,

1.41.0 · Source

impl<Ptr, Q> PartialEq<Pin<Q>> for Pin<Ptr>
where Ptr: Deref, Q: Deref, <Ptr as Deref>::Target: PartialEq<<Q as Deref>::Target>,



impl<R> PartialEq for Attribute<R>
where R: PartialEq + Reader,



impl<R> PartialEq for DebugFrame<R>
where R: PartialEq + Reader,



impl<R> PartialEq for EhFrame<R>
where R: PartialEq + Reader,



impl<R> PartialEq for EhFrameHdr<R>
where R: PartialEq + Reader,



impl<R> PartialEq for EvaluationResult<R>
where R: PartialEq + Reader, <R as Reader>::Offset: PartialEq,



impl<R> PartialEq for Expression<R>
where R: PartialEq + Reader,



impl<R> PartialEq for LocationListEntry<R>
where R: PartialEq + Reader,



impl<R, Offset> PartialEq for ArangeHeader<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for AttributeValue<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for CommonInformationEntry<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for CompleteLineProgram<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for FileEntry<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for FrameDescriptionEntry<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for IncompleteLineProgram<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for LineInstruction<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for LineProgramHeader<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for Location<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for Operation<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for Piece<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,



impl<R, Offset> PartialEq for UnitHeader<R, Offset>
where R: PartialEq + Reader<Offset = Offset>, Offset: PartialEq + ReaderOffset,

Source

impl<Section, Symbol> PartialEq for object::common::SymbolFlags<Section, Symbol>
where Section: PartialEq, Symbol: PartialEq,

Source

impl<Src, Dst> PartialEq for AlignmentError<Src, Dst>
where Src: PartialEq, Dst: PartialEq + ?Sized,

Source

impl<Src, Dst> PartialEq for SizeError<Src, Dst>
where Src: PartialEq, Dst: PartialEq + ?Sized,

Source

impl<Src, Dst> PartialEq for ValidityError<Src, Dst>
where Src: PartialEq, Dst: PartialEq + TryFromBytes + ?Sized,

1.17.0 (const: unstable) · Source

impl<T> PartialEq for Bound<T>
where T: PartialEq,

1.0.0 (const: unstable) · Source

impl<T> PartialEq for Option<T>
where T: PartialEq,

1.36.0 · Source

impl<T> PartialEq for Poll<T>
where T: PartialEq,

Source

impl<T> PartialEq for SendTimeoutError<T>
where T: PartialEq,

1.0.0 · Source

impl<T> PartialEq for TrySendError<T>
where T: PartialEq,

1.0.0 · Source

impl<T> PartialEq for *const T
where T: ?Sized,

Pointer equality is by address, as produced by the <*const T>::addr method.

1.0.0 · Source

impl<T> PartialEq for *mut T
where T: ?Sized,

Pointer equality is by address, as produced by the <*mut T>::addr method.

1.0.0 (const: unstable) · Source

impl<T> PartialEq for (T₁, T₂, …, Tₙ)
where T: PartialEq,

This trait is implemented for tuples up to twelve items long.

Source

impl<T> PartialEq for ScalarBitSet<T>
where T: PartialEq,

Source

impl<T> PartialEq for once_cell::sync::OnceCell<T>
where T: PartialEq,

Source

impl<T> PartialEq for once_cell::unsync::OnceCell<T>
where T: PartialEq,

Source

impl<T> PartialEq for Unalign<T>
where T: Unaligned + PartialEq,

Source

impl<T> PartialEq for PackedOption<T>



impl<T> PartialEq for wasmtime_environ::prelude::IndexSet<T>
where T: PartialEq + Hash + Ord,

Source

impl<T> PartialEq for EntityList<T>

Source

impl<T> PartialEq for ListPool<T>



impl<T> PartialEq for Set<T>
where T: Eq + Hash,

1.0.0 · Source

impl<T> PartialEq for Cell<T>
where T: PartialEq + Copy,

1.70.0 · Source

impl<T> PartialEq for wasmtime_environ::__core::cell::OnceCell<T>
where T: PartialEq,

1.0.0 · Source

impl<T> PartialEq for RefCell<T>
where T: PartialEq + ?Sized,

1.19.0 (const: unstable) · Source

impl<T> PartialEq for Reverse<T>
where T: PartialEq,

Source

impl<T> PartialEq for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> PartialEq for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialEq for PhantomData<T>
where T: ?Sized,

Source

impl<T> PartialEq for PhantomInvariant<T>
where T: ?Sized,

1.21.0 · Source

impl<T> PartialEq for Discriminant<T>

1.20.0 · Source

impl<T> PartialEq for ManuallyDrop<T>
where T: PartialEq + ?Sized,

Source

impl<T> PartialEq for TraitImpl<T>
where T: PartialEq + ?Sized,

1.28.0 (const: unstable) · Source

impl<T> PartialEq for NonZero<T>

1.74.0 · Source

impl<T> PartialEq for Saturating<T>
where T: PartialEq,

1.0.0 · Source

impl<T> PartialEq for Wrapping<T>
where T: PartialEq,

1.25.0 · Source

impl<T> PartialEq for NonNull<T>
where T: ?Sized,

1.0.0 · Source

impl<T> PartialEq for Cursor<T>
where T: PartialEq,

1.0.0 · Source

impl<T> PartialEq for SendError<T>
where T: PartialEq,

1.70.0 · Source

impl<T> PartialEq for OnceLock<T>
where T: PartialEq,



impl<T> PartialEq for CallFrameInstruction<T>
where T: PartialEq + ReaderOffset,



impl<T> PartialEq for CfaRule<T>
where T: PartialEq + ReaderOffset,



impl<T> PartialEq for DebugAbbrevOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugAddrBase<T>
where T: PartialEq,



impl<T> PartialEq for DebugAddrIndex<T>
where T: PartialEq,



impl<T> PartialEq for DebugArangesOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugFrameOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugInfoOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugLineOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugLineStrOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugLocListsBase<T>
where T: PartialEq,



impl<T> PartialEq for DebugLocListsIndex<T>
where T: PartialEq,



impl<T> PartialEq for DebugMacinfoOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugMacroOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugRngListsBase<T>
where T: PartialEq,



impl<T> PartialEq for DebugRngListsIndex<T>
where T: PartialEq,



impl<T> PartialEq for DebugStrOffset<T>
where T: PartialEq,



impl<T> PartialEq for DebugStrOffsetsBase<T>
where T: PartialEq,



impl<T> PartialEq for DebugStrOffsetsIndex<T>
where T: PartialEq,



impl<T> PartialEq for DebugTypesOffset<T>
where T: PartialEq,



impl<T> PartialEq for DieReference<T>
where T: PartialEq,



impl<T> PartialEq for EhFrameOffset<T>
where T: PartialEq,



impl<T> PartialEq for LocationListsOffset<T>
where T: PartialEq,



impl<T> PartialEq for RangeListsOffset<T>
where T: PartialEq,



impl<T> PartialEq for RawRangeListsOffset<T>
where T: PartialEq,



impl<T> PartialEq for RegisterRule<T>
where T: PartialEq + ReaderOffset,



impl<T> PartialEq for UnitOffset<T>
where T: PartialEq,



impl<T> PartialEq for UnitSectionOffset<T>
where T: PartialEq,



impl<T> PartialEq for UnwindExpression<T>
where T: PartialEq + ReaderOffset,

1.0.0 · Source

impl<T, A> PartialEq for wasmtime_environ::prelude::Box<T, A>
where T: PartialEq + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialEq for BTreeSet<T, A>
where T: PartialEq, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> PartialEq for LinkedList<T, A>
where T: PartialEq, A: Allocator,

1.0.0 · Source

impl<T, A> PartialEq for VecDeque<T, A>
where T: PartialEq, A: Allocator,

1.0.0 · Source

impl<T, A> PartialEq for Rc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

Source

impl<T, A> PartialEq for UniqueRc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> PartialEq for Arc<T, A>
where T: PartialEq + ?Sized, A: Allocator,

Source

impl<T, A> PartialEq for UniqueArc<T, A>
where T: PartialEq + ?Sized, A: Allocator,



impl<T, A> PartialEq for Box<T, A>
where T: PartialEq + ?Sized, A: Allocator,



impl<T, A> PartialEq for UnwindContext<T, A>
where T: PartialEq + ReaderOffset, A: PartialEq + UnwindContextStorage<T>, <A as UnwindContextStorage<T>>::Stack: PartialEq,

Source

impl<T, B> PartialEq for Ref<B, T>

1.0.0 (const: unstable) · Source

impl<T, E> PartialEq for Result<T, E>
where T: PartialEq, E: PartialEq,

Source

impl<T, S1, S2> PartialEq<IndexSet<T, S2>> for indexmap::set::IndexSet<T, S1>
where T: Hash + Eq, S1: BuildHasher, S2: BuildHasher,

Source

impl<T, S> PartialEq for AHashSet<T, S>
where T: Eq + Hash, S: BuildHasher,



impl<T, S> PartialEq for UnwindTableRow<T, S>
where T: PartialEq + ReaderOffset, S: PartialEq + UnwindContextStorage<T>,

Source

impl<T, S, A> PartialEq for hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S, A> PartialEq for hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

1.0.0 · Source

impl<T, S, A> PartialEq for std::collections::hash::set::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

1.0.0 · Source

impl<T, U> PartialEq<&[U]> for Cow<'_, [T]>
where T: PartialEq<U> + Clone,

1.0.0 · Source

impl<T, U> PartialEq<&mut [U]> for Cow<'_, [T]>
where T: PartialEq<U> + Clone,

1.0.0 (const: unstable) · Source

impl<T, U> PartialEq<[U]> for [T]
where T: PartialEq<U>,

Source

impl<T, U> PartialEq<[U]> for indexmap::set::slice::Slice<T>
where T: PartialEq<U>,

Source

impl<T, U> PartialEq<Slice<U>> for [T]
where T: PartialEq<U>,

Source

impl<T, U> PartialEq<Slice<U>> for indexmap::set::slice::Slice<T>
where T: PartialEq<U>,

Source

impl<T, U> PartialEq<Exclusive<U>> for Exclusive<T>
where T: Sync + PartialEq<U> + ?Sized, U: Sync + ?Sized,

1.0.0 · Source

impl<T, U, A1, A2> PartialEq<Vec<U, A2>> for wasmtime_environ::prelude::Vec<T, A1>
where A1: Allocator, A2: Allocator, T: PartialEq<U>,



impl<T, U, A1, A2> PartialEq<Vec<U, A2>> for Vec<T, A1>
where A1: Allocator, A2: Allocator, T: PartialEq<U>,

1.0.0 · Source

impl<T, U, A> PartialEq<&[U]> for wasmtime_environ::prelude::Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 · Source

impl<T, U, A> PartialEq<&[U]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,



impl<T, U, A> PartialEq<&[U]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 · Source

impl<T, U, A> PartialEq<&mut [U]> for wasmtime_environ::prelude::Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 · Source

impl<T, U, A> PartialEq<&mut [U]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,



impl<T, U, A> PartialEq<&mut [U]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.48.0 · Source

impl<T, U, A> PartialEq<[U]> for wasmtime_environ::prelude::Vec<T, A>
where A: Allocator, T: PartialEq<U>,



impl<T, U, A> PartialEq<[U]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.46.0 · Source

impl<T, U, A> PartialEq<Vec<U, A>> for &[T]
where A: Allocator, T: PartialEq<U>,

1.46.0 · Source

impl<T, U, A> PartialEq<Vec<U, A>> for &mut [T]
where A: Allocator, T: PartialEq<U>,

1.0.0 · Source

impl<T, U, A> PartialEq<Vec<U, A>> for Cow<'_, [T]>
where A: Allocator, T: PartialEq<U> + Clone,

1.48.0 · Source

impl<T, U, A> PartialEq<Vec<U, A>> for [T]
where A: Allocator, T: PartialEq<U>,

1.17.0 · Source

impl<T, U, A> PartialEq<Vec<U, A>> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,



impl<T, U, A> PartialEq<Vec<U, A>> for &[T]
where A: Allocator, T: PartialEq<U>,



impl<T, U, A> PartialEq<Vec<U, A>> for &mut [T]
where A: Allocator, T: PartialEq<U>,



impl<T, U, A> PartialEq<Vec<U, A>> for Cow<'_, [T]>
where A: Allocator, T: PartialEq<U> + Clone,



impl<T, U, A> PartialEq<Vec<U, A>> for [T]
where A: Allocator, T: PartialEq<U>,

1.0.0 · Source

impl<T, U, A, const N: usize> PartialEq<&[U; N]> for wasmtime_environ::prelude::Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 · Source

impl<T, U, A, const N: usize> PartialEq<&[U; N]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,



impl<T, U, A, const N: usize> PartialEq<&[U; N]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 · Source

impl<T, U, A, const N: usize> PartialEq<&mut [U; N]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 · Source

impl<T, U, A, const N: usize> PartialEq<[U; N]> for wasmtime_environ::prelude::Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.17.0 · Source

impl<T, U, A, const N: usize> PartialEq<[U; N]> for VecDeque<T, A>
where A: Allocator, T: PartialEq<U>,



impl<T, U, A, const N: usize> PartialEq<[U; N]> for Vec<T, A>
where A: Allocator, T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<&[U]> for [T; N]
where T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<&mut [U]> for [T; N]
where T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<[U; N]> for &[T]
where T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<[U; N]> for &mut [T]
where T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<[U; N]> for [T; N]
where T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<[U; N]> for [T]
where T: PartialEq<U>,

Source

impl<T, U, const N: usize> PartialEq<[U; N]> for indexmap::set::slice::Slice<T>
where T: PartialEq<U>,

1.0.0 (const: unstable) · Source

impl<T, U, const N: usize> PartialEq<[U]> for [T; N]
where T: PartialEq<U>,

Source

impl<T, const N: usize> PartialEq for Mask<T, N>

Source

impl<T, const N: usize> PartialEq for Simd<T, N>

Source

impl<T, const N: usize, U> PartialEq<Slice<U>> for [T; N]
where T: PartialEq<U>,

Source

impl<Y, R> PartialEq for CoroutineState<Y, R>
where Y: PartialEq, R: PartialEq,

Source

impl<const N: usize> PartialEq<&[u8; N]> for ByteStr

Source

impl<const N: usize> PartialEq<&[u8; N]> for ByteString

Source

impl<const N: usize> PartialEq<ByteStr> for &[u8; N]

Source

impl<const N: usize> PartialEq<ByteStr> for [u8; N]

Source

impl<const N: usize> PartialEq<ByteString> for &[u8; N]

Source

impl<const N: usize> PartialEq<ByteString> for [u8; N]

Source

impl<const N: usize> PartialEq<[u8; N]> for ByteStr

Source

impl<const N: usize> PartialEq<[u8; N]> for ByteString